@@ -63,10 +63,11 @@ from .basis import LatticeBasis
 from .structure import LatticeStructure
 from .lattice import Lattice
 
-from ._version import get_versions
+try:
+    from ._version import version as __version__
+except ImportError:
+    __version__ = "0.0.0"
 
-__version__ = get_versions()["version"]
-del get_versions
 
 # =========================================================================
 #                             1D Lattices
