@@ -7,3 +7,7 @@
 # This code is licensed under the MIT License. The copyright notice in the
 # LICENSE file in the root directory and this permission notice shall
 # be included in all copies or substantial portions of the Software.
+
+from hypothesis import settings
+
+settings.register_profile("lattpy", deadline=1000)
